# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: put_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12put_schedule.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\"}\n\x03Put\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05level\x18\x03 \x01(\x01\"#\n\nLevelBasis\x12\x07\n\x03PAR\x10\x00\x12\x0c\n\x08\x41\x43\x43RETED\x10\x01\"v\n\x0bPutSchedule\x12\x1d\n\x08schedule\x18\x01 \x03(\x0b\x32\x0b.banchi.Put\x12\x17\n\x0f\x66orfeit_accrued\x18\x02 \x01(\x08\x12/\n\x0fput_level_basis\x18\x05 \x01(\x0e\x32\x16.banchi.Put.LevelBasisb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'put_schedule_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUT._serialized_start=42
  _PUT._serialized_end=167
  _PUT_LEVELBASIS._serialized_start=132
  _PUT_LEVELBASIS._serialized_end=167
  _PUTSCHEDULE._serialized_start=169
  _PUTSCHEDULE._serialized_end=287
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: currency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63urrency.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\"4\n\x08\x43urrency\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfoJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'currency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CURRENCY._serialized_start=45
  _CURRENCY._serialized_end=97
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x65nums.proto\x12\x06\x62\x61nchi\"5\n\x03\x41lt\".\n\x0c\x43urrencyType\x12\x0e\n\nINSTRUMENT\x10\x00\x12\x0e\n\nUNDERLYING\x10\x01*2\n\x14\x45xerciseScheduleType\x12\x0c\n\x08\x45UROPEAN\x10\x00\x12\x0c\n\x08\x41MERICAN\x10\x01*x\n\x0b\x43ompounding\x12\x0e\n\nCONTINUOUS\x10\x00\x12\n\n\x06\x41NNUAL\x10\x01\x12\x0e\n\nSEMIANNUAL\x10\x02\x12\r\n\tQUARTERLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\n\n\x06WEEKLY\x10\x05\x12\t\n\x05\x44\x41ILY\x10\x06\x12\n\n\x06SIMPLE\x10\n*b\n\x10PaymentFrequency\x12\x11\n\rPAID_ANNUALLY\x10\x00\x12\x15\n\x11PAID_SEMIANNUALLY\x10\x01\x12\x12\n\x0ePAID_QUARTERLY\x10\x02\x12\x10\n\x0cPAID_MONTHLY\x10\x03*8\n\x11ReferenceRateType\x12\x19\n\x15\x43OMPOUNDED_IN_ARREARS\x10\x00\x12\x08\n\x04TERM\x10\x01*%\n\x08\x44\x61ysType\x12\x0c\n\x08\x43\x41LENDAR\x10\x00\x12\x0b\n\x07TRADING\x10\x01*A\n\x0b\x46XRateBasis\x12\x18\n\x14\x46OREIGN_PER_DOMESTIC\x10\x00\x12\x18\n\x14\x44OMESTIC_PER_FOREIGN\x10\x01*V\n\x16\x43ontractualFXRateBasis\x12\x1d\n\x19INSTRUMENT_PER_UNDERLYING\x10\x00\x12\x1d\n\x19UNDERLYING_PER_INSTRUMENT\x10\x01*.\n\x0c\x43urrencyType\x12\x0e\n\nUNDERLYING\x10\x00\x12\x0e\n\nINSTRUMENT\x10\x01*k\n\x0eRollConvention\x12\x0b\n\x07NO_ROLL\x10\x00\x12\r\n\tFOLLOWING\x10\x01\x12\x16\n\x12MODIFIED_FOLLOWING\x10\x02\x12\r\n\tPRECEDING\x10\x03\x12\x16\n\x12MODIFIED_PRECEDING\x10\x04*c\n\x17SharePriceReferenceType\x12\x0f\n\x0b\x43LOSE_PRICE\x10\x00\x12\x0e\n\nOPEN_PRICE\x10\x01\x12\x0e\n\nHIGH_PRICE\x10\x02\x12\r\n\tLOW_PRICE\x10\x03\x12\x08\n\x04VWAP\x10\x04*Q\n\x13\x46XRateReferenceType\x12\x0e\n\nCLOSE_RATE\x10\x00\x12\r\n\tOPEN_RATE\x10\x01\x12\r\n\tHIGH_RATE\x10\x02\x12\x0c\n\x08LOW_RATE\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXERCISESCHEDULETYPE._serialized_start=78
  _EXERCISESCHEDULETYPE._serialized_end=128
  _COMPOUNDING._serialized_start=130
  _COMPOUNDING._serialized_end=250
  _PAYMENTFREQUENCY._serialized_start=252
  _PAYMENTFREQUENCY._serialized_end=350
  _REFERENCERATETYPE._serialized_start=352
  _REFERENCERATETYPE._serialized_end=408
  _DAYSTYPE._serialized_start=410
  _DAYSTYPE._serialized_end=447
  _FXRATEBASIS._serialized_start=449
  _FXRATEBASIS._serialized_end=514
  _CONTRACTUALFXRATEBASIS._serialized_start=516
  _CONTRACTUALFXRATEBASIS._serialized_end=602
  _CURRENCYTYPE._serialized_start=604
  _CURRENCYTYPE._serialized_end=650
  _ROLLCONVENTION._serialized_start=652
  _ROLLCONVENTION._serialized_end=759
  _SHAREPRICEREFERENCETYPE._serialized_start=761
  _SHAREPRICEREFERENCETYPE._serialized_end=860
  _FXRATEREFERENCETYPE._serialized_start=862
  _FXRATEREFERENCETYPE._serialized_end=943
  _ALT._serialized_start=23
  _ALT._serialized_end=76
  _ALT_CURRENCYTYPE._serialized_start=30
  _ALT_CURRENCYTYPE._serialized_end=76
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: output.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0coutput.proto\x12\x06\x62\x61nchi\"\x84\x01\n\nOutputInfo\x12\x11\n\trequested\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.banchi.OutputInfo.Status\"\'\n\x06Status\x12\t\n\x05UNSET\x10\x00\x12\x07\n\x03SET\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"?\n\x0cOutputDouble\x12\r\n\x05value\x18\x01 \x01(\x01\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfo\"=\n\nOutputBool\x12\r\n\x05value\x18\x01 \x01(\x08\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'output_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OUTPUTINFO._serialized_start=25
  _OUTPUTINFO._serialized_end=157
  _OUTPUTINFO_STATUS._serialized_start=118
  _OUTPUTINFO_STATUS._serialized_end=157
  _OUTPUTDOUBLE._serialized_start=159
  _OUTPUTDOUBLE._serialized_end=222
  _OUTPUTBOOL._serialized_start=224
  _OUTPUTBOOL._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make_whole.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import enums_pb2 as enums__pb2
import matrix_pb2 as matrix__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10make_whole.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0b\x65nums.proto\x1a\x0cmatrix.proto\"\xd8\x07\n\tMakeWhole\x12*\n\x08schedule\x18\x01 \x03(\x0b\x32\x18.banchi.MakeWhole.Period\x12\x15\n\rtable_strikes\x18\x03 \x03(\x01\x12!\n\x0btable_dates\x18\x04 \x03(\x0b\x32\x0c.banchi.Date\x12*\n\x0ctable_values\x18\x05 \x01(\x0b\x32\x14.banchi.DoubleMatrix\x12:\n\x10table_value_type\x18\x06 \x01(\x0e\x32 .banchi.MakeWhole.TableValueType\x12\x33\n\x15table_strike_currency\x18\x0c \x01(\x0e\x32\x14.banchi.CurrencyType\x12\x42\n\x14\x63oupon_discount_type\x18\x07 \x01(\x0e\x32$.banchi.MakeWhole.CouponDiscountType\x12\x38\n\x1b\x63oupon_discount_compounding\x18\x08 \x01(\x0e\x32\x13.banchi.Compounding\x12\x33\n\x19\x63oupon_discount_day_count\x18\t \x01(\x0e\x32\x10.banchi.DayCount\x1a\xb0\x02\n\x06Period\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.banchi.MakeWhole.Type\x12\x0f\n\x07on_call\x18\x06 \x01(\x08\x12\x15\n\ron_conversion\x18\x07 \x01(\x08\x12\x1c\n\x14on_forced_conversion\x18\x08 \x01(\x08\x12\x13\n\x0bon_takeover\x18\t \x01(\x08\x12\x15\n\rinitial_value\x18\x0b \x01(\x01\x12\x14\n\x0c\x64\x65\x63rement_by\x18\x0c \x01(\x01\x12\x17\n\x0f\x64iscount_spread\x18\x0e \x01(\x01\x12\x15\n\rdiscount_rate\x18\x10 \x01(\x01J\x04\x08\x0f\x10\x10\"k\n\x04Type\x12\x17\n\x13REMAINING_COUPON_PV\x10\x00\x12\x14\n\x10\x43OUPON_DECREMENT\x10\x01\x12\x14\n\x10\x41NNUAL_DECREMENT\x10\x02\x12\x13\n\x0f\x44\x41ILY_DECREMENT\x10\x03\x12\t\n\x05TABLE\x10\t\"4\n\x0eTableValueType\x12\x10\n\x0c\x45XTRA_SHARES\x10\x00\x12\x10\n\x0cTOTAL_SHARES\x10\x01\"?\n\x12\x43ouponDiscountType\x12\x0e\n\nFIXED_RATE\x10\x00\x12\x19\n\x15SPREAD_OVER_BENCHMARK\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make_whole_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MAKEWHOLE._serialized_start=68
  _MAKEWHOLE._serialized_end=1052
  _MAKEWHOLE_PERIOD._serialized_start=520
  _MAKEWHOLE_PERIOD._serialized_end=824
  _MAKEWHOLE_TYPE._serialized_start=826
  _MAKEWHOLE_TYPE._serialized_end=933
  _MAKEWHOLE_TABLEVALUETYPE._serialized_start=935
  _MAKEWHOLE_TABLEVALUETYPE._serialized_end=987
  _MAKEWHOLE_COUPONDISCOUNTTYPE._serialized_start=989
  _MAKEWHOLE_COUPONDISCOUNTTYPE._serialized_end=1052
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bquery.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\"\x1d\n\x0fPrecannedFilter\x12\n\n\x02id\x18\x01 \x01(\t\"\x87\x02\n\x0cSimpleFilter\x12\x16\n\x0e\x61ttribute_name\x18\x01 \x01(\t\x12)\n\x02op\x18\x02 \x01(\x0e\x32\x1d.banchi.SimpleFilter.Operator\x12\r\n\x05value\x18\x03 \x01(\t\"\xa4\x01\n\x08Operator\x12\x0c\n\x08\x43ONTAINS\x10\x00\x12\x14\n\x10\x44OES_NOT_CONTAIN\x10\x01\x12\n\n\x06\x45QUALS\x10\x02\x12\x12\n\x0e\x44OES_NOT_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x1a\n\x16GREATER_THAN_OR_EQUALS\x10\x05\x12\r\n\tLESS_THAN\x10\x06\x12\x17\n\x13LESS_THAN_OR_EQUALS\x10\x07\"\x1d\n\x0e\x41\x64vancedFilter\x12\x0b\n\x03str\x18\x01 \x01(\t\"\xe4\x01\n\x06\x46ilter\x12\'\n\x04type\x18\x03 \x01(\x0e\x32\x19.banchi.Filter.FilterType\x12*\n\tprecanned\x18\x04 \x01(\x0b\x32\x17.banchi.PrecannedFilter\x12$\n\x06simple\x18\x05 \x01(\x0b\x32\x14.banchi.SimpleFilter\x12(\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x16.banchi.AdvancedFilter\"5\n\nFilterType\x12\r\n\tPRECANNED\x10\x00\x12\n\n\x06SIMPLE\x10\x01\x12\x0c\n\x08\x41\x44VANCED\x10\x02\"x\n\x0cQueryElement\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.banchi.Filter\x12*\n\x02op\x18\x02 \x01(\x0e\x32\x1e.banchi.QueryElement.LogicalOp\"\x1c\n\tLogicalOp\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\"r\n\x05Query\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12&\n\x08\x65lements\x18\x04 \x03(\x0b\x32\x14.banchi.QueryElement\x12\x11\n\tobj_types\x18\x05 \x03(\tJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRECANNEDFILTER._serialized_start=42
  _PRECANNEDFILTER._serialized_end=71
  _SIMPLEFILTER._serialized_start=74
  _SIMPLEFILTER._serialized_end=337
  _SIMPLEFILTER_OPERATOR._serialized_start=173
  _SIMPLEFILTER_OPERATOR._serialized_end=337
  _ADVANCEDFILTER._serialized_start=339
  _ADVANCEDFILTER._serialized_end=368
  _FILTER._serialized_start=371
  _FILTER._serialized_end=599
  _FILTER_FILTERTYPE._serialized_start=546
  _FILTER_FILTERTYPE._serialized_end=599
  _QUERYELEMENT._serialized_start=601
  _QUERYELEMENT._serialized_end=721
  _QUERYELEMENT_LOGICALOP._serialized_start=693
  _QUERYELEMENT_LOGICALOP._serialized_end=721
  _QUERY._serialized_start=723
  _QUERY._serialized_end=837
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yield_curve.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import offset_pb2 as offset__pb2
import enums_pb2 as enums__pb2
import output_pb2 as output__pb2
import object_info_pb2 as object__info__pb2
import calendar_pb2 as calendar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11yield_curve.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0coffset.proto\x1a\x0b\x65nums.proto\x1a\x0coutput.proto\x1a\x11object_info.proto\x1a\x0e\x63\x61lendar.proto\">\n\x0e\x43urveSwapEntry\x12\x1e\n\x06offset\x18\x01 \x01(\x0b\x32\x0e.banchi.Offset\x12\x0c\n\x04rate\x18\x02 \x01(\x01\">\n\x0e\x43urveCashEntry\x12\x1e\n\x06offset\x18\x01 \x01(\x0b\x32\x0e.banchi.Offset\x12\x0c\n\x04rate\x18\x02 \x01(\x01\";\n\nCurveEntry\x12\x1e\n\x06offset\x18\x01 \x01(\x0b\x32\x0e.banchi.Offset\x12\r\n\x05value\x18\x02 \x01(\x01\"\x91\x05\n\nYieldCurve\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x0ereference_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x17.banchi.YieldCurve.Type\x12\x11\n\tflat_rate\x18\x05 \x01(\x01\x12#\n\tday_count\x18\x06 \x01(\x0e\x32\x10.banchi.DayCount\x12(\n\x0b\x63ompounding\x18\x07 \x01(\x0e\x32\x13.banchi.Compounding\x12!\n\x05\x63urve\x18\n \x03(\x0b\x32\x12.banchi.CurveEntry\x12\x18\n\x10settlement_delay\x18\x0b \x01(\x05\x12\"\n\x08\x63\x61lendar\x18\x0c \x01(\x0b\x32\x10.banchi.Calendar\x12*\n\ncash_rates\x18\x0e \x03(\x0b\x32\x16.banchi.CurveCashEntry\x12*\n\nswap_rates\x18\x11 \x03(\x0b\x32\x16.banchi.CurveSwapEntry\x12-\n\x13\x63\x61sh_rate_day_count\x18\x14 \x01(\x0e\x32\x10.banchi.DayCount\x12-\n\x13swap_rate_day_count\x18\x15 \x01(\x0e\x32\x10.banchi.DayCount\x12\x38\n\x16swap_payment_frequency\x18\x16 \x01(\x0e\x32\x18.banchi.PaymentFrequency\"K\n\x04Type\x12\r\n\tFLAT_RATE\x10\x00\x12\x0e\n\nZERO_RATES\x10\x01\x12\x14\n\x10\x44ISCOUNT_FACTORS\x10\x02\x12\x0e\n\nSWAP_CURVE\x10\x03J\x04\x08\x01\x10\x02\"Q\n\x0bOutputCurve\x12 \n\x05value\x18\x01 \x03(\x0b\x32\x11.banchi.DateValue\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfo\"\x97\x01\n\x11YieldCurveOutputs\x12-\n\x10\x64iscount_factors\x18\x01 \x01(\x0b\x32\x13.banchi.OutputCurve\x12\'\n\nzero_rates\x18\x03 \x01(\x0b\x32\x13.banchi.OutputCurve\x12*\n\rforward_rates\x18\x05 \x01(\x0b\x32\x13.banchi.OutputCurve\"\xda\x01\n\x0eYieldCurveCalc\x12\"\n\x06object\x18\x01 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\'\n\x0binput_curve\x18\x02 \x01(\x0b\x32\x12.banchi.YieldCurve\x12+\n\x15output_reference_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\"\n\x0c\x63ustom_dates\x18\x04 \x03(\x0b\x32\x0c.banchi.Date\x12*\n\x07outputs\x18\x0f \x01(\x0b\x32\x19.banchi.YieldCurveOutputs\":\n\x11YieldCurveCalcSet\x12%\n\x05\x63\x61lcs\x18\x01 \x03(\x0b\x32\x16.banchi.YieldCurveCalcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yield_curve_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CURVESWAPENTRY._serialized_start=117
  _CURVESWAPENTRY._serialized_end=179
  _CURVECASHENTRY._serialized_start=181
  _CURVECASHENTRY._serialized_end=243
  _CURVEENTRY._serialized_start=245
  _CURVEENTRY._serialized_end=304
  _YIELDCURVE._serialized_start=307
  _YIELDCURVE._serialized_end=964
  _YIELDCURVE_TYPE._serialized_start=883
  _YIELDCURVE_TYPE._serialized_end=958
  _OUTPUTCURVE._serialized_start=966
  _OUTPUTCURVE._serialized_end=1047
  _YIELDCURVEOUTPUTS._serialized_start=1050
  _YIELDCURVEOUTPUTS._serialized_end=1201
  _YIELDCURVECALC._serialized_start=1204
  _YIELDCURVECALC._serialized_end=1422
  _YIELDCURVECALCSET._serialized_start=1424
  _YIELDCURVECALCSET._serialized_end=1482
# @@protoc_insertion_point(module_scope)



from banchi.objects.date_pb2 import Date
from datetime import datetime, date, timedelta

serial_number_ref_date = date(1899, 12, 30)

def to_pydate(banchi_date):
  if (banchi_date.serial_number == 0):
    return None
  py_date = serial_number_ref_date
  py_date += timedelta(days=banchi_date.serial_number)
  return py_date

def from_pydate(py_date):
  banchi_date = Date()
  if (py_date != None):
    banchi_date.serial_number = (py_date - serial_number_ref_date).days
  return banchi_date


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: convertible.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import output_pb2 as output__pb2
import cashflows_pb2 as cashflows__pb2
import yield_curve_pb2 as yield__curve__pb2
import stock_pb2 as stock__pb2
import bond_pb2 as bond__pb2
import currency_pb2 as currency__pb2
import interest_rate_index_pb2 as interest__rate__index__pb2
import model_parameters_pb2 as model__parameters__pb2
import object_info_pb2 as object__info__pb2
import credit_data_pb2 as credit__data__pb2
import fx_rate_pb2 as fx__rate__pb2
import conversion_pb2 as conversion__pb2
import convertible_call_schedule_pb2 as convertible__call__schedule__pb2
import put_schedule_pb2 as put__schedule__pb2
import dividend_protection_pb2 as dividend__protection__pb2
import make_whole_pb2 as make__whole__pb2
import market_pb2 as market__pb2
import calendar_pb2 as calendar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63onvertible.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0coutput.proto\x1a\x0f\x63\x61shflows.proto\x1a\x11yield_curve.proto\x1a\x0bstock.proto\x1a\nbond.proto\x1a\x0e\x63urrency.proto\x1a\x19interest_rate_index.proto\x1a\x16model_parameters.proto\x1a\x11object_info.proto\x1a\x11\x63redit_data.proto\x1a\rfx_rate.proto\x1a\x10\x63onversion.proto\x1a\x1f\x63onvertible_call_schedule.proto\x1a\x12put_schedule.proto\x1a\x19\x64ividend_protection.proto\x1a\x10make_whole.proto\x1a\x0cmarket.proto\x1a\x0e\x63\x61lendar.proto\"\x92\x03\n\x0b\x43onvertible\x12&\n\nconversion\x18\x02 \x01(\x0b\x32\x12.banchi.Conversion\x12\x31\n\x10\x63onvertible_type\x18\x03 \x01(\x0e\x32\x17.banchi.ConvertibleType\x12!\n\x04\x62ond\x18\x05 \x01(\x0b\x32\x13.banchi.BondDetails\x12.\n\x05\x63\x61lls\x18\x07 \x01(\x0b\x32\x1f.banchi.ConvertibleCallSchedule\x12!\n\x04puts\x18\x08 \x01(\x0b\x32\x13.banchi.PutSchedule\x12\"\n\x08\x63urrency\x18\t \x01(\x0b\x32\x10.banchi.Currency\x12\x37\n\x13\x64ividend_protection\x18\x0b \x01(\x0b\x32\x1a.banchi.DividendProtection\x12%\n\nmake_whole\x18\x0c \x01(\x0b\x32\x11.banchi.MakeWhole\x12(\n\x12\x66inancial_year_end\x18\x14 \x01(\x0b\x32\x0c.banchi.DateJ\x04\x08\x01\x10\x02\"\xf2\x06\n\x12\x43onvertibleOutputs\x12\"\n\x04theo\x18\x01 \x01(\x0b\x32\x14.banchi.OutputDouble\x12)\n\x0b\x64irty_price\x18\x02 \x01(\x0b\x32\x14.banchi.OutputDouble\x12)\n\x0b\x63lean_price\x18\x03 \x01(\x0b\x32\x14.banchi.OutputDouble\x12(\n\ntheo_price\x18\x04 \x01(\x0b\x32\x14.banchi.OutputDouble\x12%\n\x07\x61\x63\x63rued\x18\x05 \x01(\x0b\x32\x14.banchi.OutputDouble\x12$\n\x06parity\x18\x07 \x01(\x0b\x32\x14.banchi.OutputDouble\x12.\n\x10prevailing_ratio\x18\x08 \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05\x64\x65lta\x18\n \x01(\x0b\x32\x14.banchi.OutputDouble\x12*\n\x0cparity_delta\x18\x0b \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05gamma\x18\x0c \x01(\x0b\x32\x14.banchi.OutputDouble\x12*\n\x0cparity_gamma\x18\r \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05theta\x18\x0e \x01(\x0b\x32\x14.banchi.OutputDouble\x12(\n\ncash_today\x18\x17 \x01(\x0b\x32\x14.banchi.OutputDouble\x12-\n\x11\x63onvertible_today\x18\x18 \x01(\x0b\x32\x12.banchi.OutputBool\x12*\n\x0e\x63\x61llable_today\x18\x19 \x01(\x0b\x32\x12.banchi.OutputBool\x12\x34\n\x16ratio_adjustment_today\x18\x1d \x01(\x0b\x32\x14.banchi.OutputDouble\x12(\n\nplain_bond\x18( \x01(\x0b\x32\x14.banchi.OutputDouble\x12=\n\x13projected_cashflows\x18) \x01(\x0b\x32 .banchi.OutputProjectedCashflows\x12P\n\x1dprojected_dividend_protection\x18\x32 \x01(\x0b\x32).banchi.OutputProjectedDividendProtection\"\xbb\x02\n\x0f\x43onvertibleInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x1e\n\x06region\x18\x04 \x01(\x0b\x32\x0e.banchi.Region\x12\x1e\n\x06sector\x18\x05 \x01(\x0b\x32\x0e.banchi.Sector\x12\x13\n\x0boutstanding\x18\x06 \x01(\x01\x12\x44\n\x1a\x63onversion_settlement_type\x18\t \x01(\x0e\x32 .banchi.ConversionSettlementType\x12\r\n\x05notes\x18\x0e \x01(\t\x12;\n\nadditional\x18\x0f \x03(\x0b\x32\'.banchi.ConvertibleInfo.AdditionalEntry\x1a\x31\n\x0f\x41\x64\x64itionalEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x05\n\x0f\x43onvertibleData\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12$\n\x0evaluation_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\'\n\ninstrument\x18\x03 \x01(\x0b\x32\x13.banchi.Convertible\x12\x1c\n\x05stock\x18\x04 \x01(\x0b\x32\r.banchi.Stock\x12\x36\n\x1ainstrument_risk_free_curve\x18\x05 \x01(\x0b\x32\x12.banchi.YieldCurve\x12\x32\n\x16instrument_credit_data\x18\x06 \x01(\x0b\x32\x12.banchi.CreditData\x12\x1f\n\x07\x66x_rate\x18\x07 \x01(\x0b\x32\x0e.banchi.FXRate\x12\x1c\n\x14\x66x_stock_correlation\x18\x08 \x01(\x01\x12-\n\x0cmarket_price\x18\t \x01(\x0b\x32\x17.banchi.BondMarketPrice\x12\x31\n\x10model_parameters\x18\n \x01(\x0b\x32\x17.banchi.ModelParameters\x12\x36\n\x1aunderlying_risk_free_curve\x18\x0c \x01(\x0b\x32\x12.banchi.YieldCurve\x12-\n\x13instrument_calendar\x18\x0e \x01(\x0b\x32\x10.banchi.Calendar\x12+\n\x07outputs\x18\x0f \x01(\x0b\x32\x1a.banchi.ConvertibleOutputs\x12\x31\n\x0e\x66loating_index\x18\x12 \x01(\x0b\x32\x19.banchi.InterestRateIndex\x12\x15\n\rrecovery_rate\x18\x14 \x01(\x01\x12%\n\x04info\x18\x33 \x01(\x0b\x32\x17.banchi.ConvertibleInfoJ\x04\x08\x01\x10\x02J\x04\x08\x32\x10\x33\"<\n\x12\x43onvertibleCalcSet\x12&\n\x05\x63\x61lcs\x18\x01 \x03(\x0b\x32\x17.banchi.ConvertibleData*1\n\x0f\x43onvertibleType\x12\x14\n\x10\x43ONVERTIBLE_BOND\x10\x00\x12\x08\n\x04PEPS\x10\x02*A\n\x18\x43onversionSettlementType\x12\x0e\n\nALL_SHARES\x10\x00\x12\x0c\n\x08\x41LL_CASH\x10\x01\x12\x07\n\x03NET\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'convertible_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONVERTIBLEINFO_ADDITIONALENTRY._options = None
  _CONVERTIBLEINFO_ADDITIONALENTRY._serialized_options = b'8\001'
  _CONVERTIBLETYPE._serialized_start=2759
  _CONVERTIBLETYPE._serialized_end=2808
  _CONVERSIONSETTLEMENTTYPE._serialized_start=2810
  _CONVERSIONSETTLEMENTTYPE._serialized_end=2875
  _CONVERTIBLE._serialized_start=383
  _CONVERTIBLE._serialized_end=785
  _CONVERTIBLEOUTPUTS._serialized_start=788
  _CONVERTIBLEOUTPUTS._serialized_end=1670
  _CONVERTIBLEINFO._serialized_start=1673
  _CONVERTIBLEINFO._serialized_end=1988
  _CONVERTIBLEINFO_ADDITIONALENTRY._serialized_start=1939
  _CONVERTIBLEINFO_ADDITIONALENTRY._serialized_end=1988
  _CONVERTIBLEDATA._serialized_start=1991
  _CONVERTIBLEDATA._serialized_end=2695
  _CONVERTIBLECALCSET._serialized_start=2697
  _CONVERTIBLECALCSET._serialized_end=2757
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx_rate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import currency_pb2 as currency__pb2
import enums_pb2 as enums__pb2
import object_info_pb2 as object__info__pb2
import ticker_pb2 as ticker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rfx_rate.proto\x12\x06\x62\x61nchi\x1a\x0e\x63urrency.proto\x1a\x0b\x65nums.proto\x1a\x11object_info.proto\x1a\x0cticker.proto\"\xb6\x01\n\x10\x46XTimeSeriesData\x12\'\n\nopen_rates\x18\x01 \x01(\x0b\x32\x13.banchi.DailyTicker\x12\'\n\nhigh_rates\x18\x02 \x01(\x0b\x32\x13.banchi.DailyTicker\x12&\n\tlow_rates\x18\x03 \x01(\x0b\x32\x13.banchi.DailyTicker\x12(\n\x0b\x63lose_rates\x18\x04 \x01(\x0b\x32\x13.banchi.DailyTicker\"\x84\x02\n\x06\x46XRate\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x11\n\tspot_rate\x18\x01 \x01(\x01\x12\'\n\nrate_basis\x18\x02 \x01(\x0e\x32\x13.banchi.FXRateBasis\x12\x12\n\nvolatility\x18\x03 \x01(\x01\x12-\n\x0btime_series\x18\x05 \x01(\x0b\x32\x18.banchi.FXTimeSeriesData\x12+\n\x11\x64omestic_currency\x18\x08 \x01(\x0b\x32\x10.banchi.Currency\x12*\n\x10\x66oreign_currency\x18\t \x01(\x0b\x32\x10.banchi.Currencyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx_rate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FXTIMESERIESDATA._serialized_start=88
  _FXTIMESERIESDATA._serialized_end=270
  _FXRATE._serialized_start=273
  _FXRATE._serialized_end=533
# @@protoc_insertion_point(module_scope)





from banchi.objects import convertible_pb2, stock_pb2, yield_curve_pb2, fx_rate_pb2, \
  credit_data_pb2, ticker_pb2, warrant_pb2, market_pb2, calendar_pb2, currency_pb2

def deserialize_binary(binary_data, type_str):
  obj = None
  if (type_str == "Calendar"):
    obj = calendar_pb2.Calendar()
  elif (type_str == "ConvertibleBond"):
    obj = convertible_pb2.ConvertibleData()
  elif (type_str == "CreditData"):
    obj = credit_data_pb2.CreditData()
  elif (type_str == "Currency"):
    obj = currency_pb2.Currency()
  elif (type_str == "DailyTicker"):
    obj = ticker_pb2.DailyTicker()
  elif (type_str == "FXRate"):
    obj = fx_rate_pb2.FXRate()
  elif (type_str == "Region"):
    obj = market_pb2.Region()
  elif (type_str == "Sector"):
    obj = market_pb2.Sector()
  elif (type_str == "Stock"):
    obj = stock_pb2.Stock()
  elif (type_str == "Warrant"):
    obj = warrant_pb2.WarrantData()
  elif (type_str == "YieldCurve"):
    obj = yield_curve_pb2.YieldCurve()
  else:
    raise Exception # todo, more specific
  obj.ParseFromString(binary_data)
  return obj



import sqlite3
from banchi.objects import convertible_pb2, stock_pb2, fx_rate_pb2
from banchi import serialization

from enum import Enum

class MarshallSubObjects(Enum):
  NONE = 1
  ALL = 2

class DataService:

  local_file = ""
  local_con = None


  def __init__(self,*,local_file):
    self.local_file = local_file
    self.local_con = sqlite3.connect(self.local_file)
  
  def marshall_sub_objects(self, obj, marshall_sub_objs):
    if(marshall_sub_objs != MarshallSubObjects.NONE):
      if (isinstance(obj, convertible_pb2.ConvertibleData)):
        obj.stock.CopyFrom(self.get_object(obj.stock.object.id, marshall_sub_objs, obj.stock))
        obj.instrument_risk_free_curve.CopyFrom(self.get_object(obj.instrument_risk_free_curve.object.id, \
          marshall_sub_objs, obj.instrument_risk_free_curve))
        obj.instrument_credit_data.CopyFrom(self.get_object(obj.instrument_credit_data.object.id, \
          marshall_sub_objs, obj.instrument_credit_data))
        obj.info.region.CopyFrom(self.get_object(obj.info.region.object.id, marshall_sub_objs, obj.info.region))
        obj.fx_rate.CopyFrom(self.get_object(obj.fx_rate.object.id, marshall_sub_objs, obj.fx_rate))
        obj.instrument_calendar.CopyFrom(self.get_object(obj.instrument_calendar.object.id, marshall_sub_objs, obj.instrument_calendar))
        obj.instrument.currency.CopyFrom(self.get_object(obj.instrument.currency.object.id, marshall_sub_objs, obj.instrument.currency))
      if (isinstance(obj, stock_pb2.Stock)):
        obj.time_series.close_prices.CopyFrom(self.get_object(obj.time_series.close_prices.object.id, \
          marshall_sub_objs, obj.time_series.close_prices))
        obj.time_series.open_prices.CopyFrom(self.get_object(obj.time_series.open_prices.object.id, \
          marshall_sub_objs, obj.time_series.open_prices))
        obj.time_series.high_prices.CopyFrom(self.get_object(obj.time_series.high_prices.object.id, \
          marshall_sub_objs, obj.time_series.high_prices))
        obj.time_series.low_prices.CopyFrom(self.get_object(obj.time_series.low_prices.object.id, \
          marshall_sub_objs, obj.time_series.low_prices))
        obj.time_series.vwaps.CopyFrom(self.get_object(obj.time_series.vwaps.object.id, \
          marshall_sub_objs, obj.time_series.vwaps))
        obj.calendar.CopyFrom(self.get_object(obj.calendar.object.id, marshall_sub_objs, obj.calendar))
        obj.info.region.CopyFrom(self.get_object(obj.info.region.object.id, marshall_sub_objs, obj.info.region))
        obj.info.sector.CopyFrom(self.get_object(obj.info.sector.object.id, marshall_sub_objs, obj.info.sector))
        obj.currency.CopyFrom(self.get_object(obj.currency.object.id, marshall_sub_objs, obj.currency))
      if (isinstance(obj, fx_rate_pb2.FXRate)):
        obj.time_series.close_rates.CopyFrom(self.get_object(obj.time_series.close_rates.object.id, \
          marshall_sub_objs, obj.time_series.close_rates))
        obj.time_series.open_rates.CopyFrom(self.get_object(obj.time_series.open_rates.object.id, \
          marshall_sub_objs, obj.time_series.open_rates))
        obj.time_series.high_rates.CopyFrom(self.get_object(obj.time_series.high_rates.object.id, \
          marshall_sub_objs, obj.time_series.high_rates))
        obj.time_series.low_rates.CopyFrom(self.get_object(obj.time_series.low_rates.object.id, \
          marshall_sub_objs, obj.time_series.low_rates))
    return obj

  def get_object(self, id, marshall_sub_objs=MarshallSubObjects.NONE, obj=None):
    if (id == ""):
      return obj
    id_split = id.split(':', 2)
    type_str = id_split[0]
    cur = self.local_con.cursor()
    res = cur.execute("SELECT Data FROM {} WHERE Id='{}'".format(type_str, id))
    binary_data = res.fetchone()[0]
    
    obj = serialization.deserialize_binary(binary_data, type_str)
    obj = self.marshall_sub_objects(obj, marshall_sub_objs)
    return obj


  def get_objects_of_type(self, type_str, marshall_sub_objs=MarshallSubObjects.NONE):
    cur = self.local_con.cursor()
    res = cur.execute("SELECT Data FROM {}".format(type_str))
    all_data = res.fetchall()
    binary_data = all_data[0]
    objs = []
    for data in all_data:
      binary_data = data[0]
      obj = serialization.deserialize_binary(binary_data, type_str)
      obj = self.marshall_sub_objects(obj, marshall_sub_objs)
      objs.append(obj)
    return objs


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: warrant_call_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import trigger_pb2 as trigger__pb2
import enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwarrant_call_schedule.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\rtrigger.proto\x1a\x0b\x65nums.proto\"\xb8\x02\n\x12WarrantCallTrigger\x12\r\n\x05level\x18\x01 \x01(\x01\x12\"\n\x04type\x18\x03 \x01(\x0e\x32\x14.banchi.Trigger.Type\x12\x35\n\x0egrace_required\x18\x06 \x01(\x0e\x32\x1d.banchi.Trigger.GraceRequired\x12\x1c\n\x14\x64\x61ys_in_grace_period\x18\x07 \x01(\x05\x12\x14\n\x0cgrace_period\x18\x08 \x01(\x05\x12\x30\n\x16grace_period_days_type\x18\t \x01(\x0e\x32\x10.banchi.DaysType\x12\x1a\n\x12grace_period_delay\x18\x0c \x01(\x05\x12\x36\n\x1cgrace_period_delay_days_type\x18\r \x01(\x0e\x32\x10.banchi.DaysType\"\x8f\x02\n\x0bWarrantCall\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05level\x18\x04 \x01(\x01\x12+\n\x07trigger\x18\x05 \x01(\x0b\x32\x1a.banchi.WarrantCallTrigger\x12\x16\n\x0eminimum_notice\x18\n \x01(\x05\x12\x16\n\x0emaximum_notice\x18\x0b \x01(\x05\x12*\n\x10notice_days_type\x18\x0c \x01(\x0e\x32\x10.banchi.DaysType\x12$\n\x1c\x63\x61shless_exercise_applicable\x18\x0f \x01(\x08\"\x8d\x02\n\x13WarrantCallSchedule\x12%\n\x08schedule\x18\x01 \x03(\x0b\x32\x13.banchi.WarrantCall\x12\x46\n\x1dtrigger_share_price_reference\x18\x06 \x01(\x0e\x32\x1f.banchi.SharePriceReferenceType\x12\x39\n\x14trigger_fx_reference\x18\x07 \x01(\x0e\x32\x1b.banchi.FXRateReferenceType\x12\x17\n\x0f\x65xercise_expiry\x18\x0e \x01(\x05\x12\x33\n\x19\x65xercise_expiry_days_type\x18\x0f \x01(\x0e\x32\x10.banchi.DaysTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'warrant_call_schedule_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WARRANTCALLTRIGGER._serialized_start=80
  _WARRANTCALLTRIGGER._serialized_end=392
  _WARRANTCALL._serialized_start=395
  _WARRANTCALL._serialized_end=666
  _WARRANTCALLSCHEDULE._serialized_start=669
  _WARRANTCALLSCHEDULE._serialized_end=938
# @@protoc_insertion_point(module_scope)



import sys
import os
import importlib
generated_dir = os.path.dirname(os.path.realpath(__file__))
sys.path.append(generated_dir) # needed so that proto generated python modules can locate their dependencies

# idea for importing dynamically, not currently working
#for module in os.listdir(generated_dir):
#    if module != '__init__.py' and module[-6:] == '_pb2.py':
#        module_name = module[:-3]
#        as_module_name = module[:-5]
#        globals()[as_module_name] = importlib.import_module(module_name, "banchi.objects")

import banchi.objects.bond_pb2 as bond
import banchi.objects.calendar_pb2 as calendar
import banchi.objects.cashflows_pb2 as cashflows
import banchi.objects.conversion_pb2 as conversion
import banchi.objects.convertible_calc_pb2 as convertible_calc
import banchi.objects.convertible_call_schedule_pb2 as convertible_call_schedule
import banchi.objects.convertible_pb2 as convertible
import banchi.objects.date_pb2 as date
import banchi.objects.dividend_protection_pb2 as dividend_protection
import banchi.objects.enums_pb2 as enums
import banchi.objects.fx_rate_pb2 as fx_rate
import banchi.objects.interest_rate_index_pb2 as interest_rate_index
import banchi.objects.make_whole_pb2 as make_whole
import banchi.objects.market_pb2 as market
import banchi.objects.matrix_pb2 as matrix
import banchi.objects.model_parameters_pb2 as model_parameters
import banchi.objects.object_info_pb2 as object_info
import banchi.objects.offset_pb2 as offset
import banchi.objects.output_pb2 as output
import banchi.objects.put_schedule_pb2 as put_schedule
import banchi.objects.stock_pb2 as stock
import banchi.objects.ticker_pb2 as ticker
import banchi.objects.trigger_pb2 as trigger
import banchi.objects.warrant_call_schedule_pb2 as warrant_call_schedule
import banchi.objects.warrant_pb2 as warrant
import banchi.objects.yield_curve_pb2 as yield_curve


import ctypes
import os, sys

banchi_home = os.getenv('BANCHILIB_HOME', default='.')

if sys.platform.startswith('linux'):
    BANCHI_C = ctypes.CDLL(banchi_home + "/lib/libbanchi_c.so")
else:
    BANCHI_C = ctypes.CDLL(banchi_home + "/bin/banchi_c")


def schema_version():
    return BANCHI_C.SchemaVersion()
    
def version_string():
    return str(BANCHI_C.MajorVersion()) + "." + str(BANCHI_C.SchemaVersion())

def calc_yield_curve(curve_calc):
    ycCalcData = curve_calc.SerializeToString()
    out_handle = ctypes.c_void_p(0)
    out_size_handle = ctypes.c_int(0)
    BANCHI_C.CalcYieldCurve(ycCalcData, len(ycCalcData), ctypes.byref(out_handle), ctypes.byref(out_size_handle))
    curve_calc.outputs.ParseFromString(ctypes.string_at(out_handle, out_size_handle))
    BANCHI_C.DeleteBuffer(out_handle)

def calc_convertible(calc):
    calc_data = calc.SerializeToString()
    out_handle = ctypes.c_void_p(0)
    out_size_handle = ctypes.c_int(0)
    BANCHI_C.CalcConvertible(calc_data, len(calc_data), ctypes.byref(out_handle), ctypes.byref(out_size_handle))
    calc.outputs.ParseFromString(ctypes.string_at(out_handle, out_size_handle))
    BANCHI_C.DeleteBuffer(out_handle)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: market_news.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11market_news.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"\xec\x01\n\nMarketNews\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12*\n\tnews_type\x18\x03 \x01(\x0e\x32\x17.banchi.MarketNews.Type\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x1a\n\x04\x64\x61te\x18\x06 \x01(\x0b\x32\x0c.banchi.Date\"N\n\x04Type\x12\x0c\n\x08MARKETUP\x10\x00\x12\x0e\n\nMARKETDOWN\x10\x02\x12\x0e\n\nMARKETFLAT\x10\x03\x12\n\n\x06REPORT\x10\x04\x12\x0c\n\x08NEWISSUE\x10\x05J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'market_news_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MARKETNEWS._serialized_start=61
  _MARKETNEWS._serialized_end=297
  _MARKETNEWS_TYPE._serialized_start=213
  _MARKETNEWS_TYPE._serialized_end=291
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import enums_pb2 as enums__pb2
import yield_curve_pb2 as yield__curve__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63redit_data.proto\x12\x06\x62\x61nchi\x1a\x0b\x65nums.proto\x1a\x11yield_curve.proto\x1a\x11object_info.proto\"\xb4\x02\n\nCreditData\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x17.banchi.CreditData.Type\x12\x13\n\x0b\x66lat_spread\x18\x04 \x01(\x01\x12/\n\x12spread_compounding\x18\x06 \x01(\x0e\x32\x13.banchi.Compounding\x12*\n\x0eterm_structure\x18\x07 \x03(\x0b\x32\x12.banchi.CurveEntry\x12\'\n\x0brisky_curve\x18\x08 \x01(\x0b\x32\x12.banchi.YieldCurve\":\n\x04Type\x12\x0f\n\x0b\x46LAT_SPREAD\x10\x00\x12\x10\n\x0cTERM_SPREADS\x10\x01\x12\x0f\n\x0bRISKY_CURVE\x10\x02J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_data_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREDITDATA._serialized_start=81
  _CREDITDATA._serialized_end=389
  _CREDITDATA_TYPE._serialized_start=325
  _CREDITDATA_TYPE._serialized_end=383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import currency_pb2 as currency__pb2
import object_info_pb2 as object__info__pb2
import ticker_pb2 as ticker__pb2
import market_pb2 as market__pb2
import calendar_pb2 as calendar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bstock.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0e\x63urrency.proto\x1a\x11object_info.proto\x1a\x0cticker.proto\x1a\x0cmarket.proto\x1a\x0e\x63\x61lendar.proto\"<\n\x0c\x43\x61shDividend\x12\x1d\n\x07\x65x_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x04 \x01(\x01\"D\n\x14ProportionalDividend\x12\x1d\n\x07\x65x_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x04 \x01(\x01\"E\n\x12\x44ividendYieldEntry\x12 \n\nstart_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05yield\x18\x02 \x01(\x01\"\x93\x02\n\tDividends\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.banchi.Dividends.Type\x12\x12\n\nflat_yield\x18\x02 \x01(\x01\x12,\n\x0e\x63\x61sh_dividends\x18\x03 \x03(\x0b\x32\x14.banchi.CashDividend\x12<\n\x16proportional_dividends\x18\x04 \x03(\x0b\x32\x1c.banchi.ProportionalDividend\x12\x33\n\x0f\x64ividend_yields\x18\x05 \x03(\x0b\x32\x1a.banchi.DividendYieldEntry\"+\n\x04Type\x12\x13\n\x0f\x46LAT_CONTINUOUS\x10\x00\x12\x0e\n\nSTRUCTURED\x10\x01\"\xc5\x01\n\tStockInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x1e\n\x06region\x18\x04 \x01(\x0b\x32\x0e.banchi.Region\x12\x1e\n\x06sector\x18\x05 \x01(\x0b\x32\x0e.banchi.Sector\x12\x35\n\nadditional\x18\x0f \x03(\x0b\x32!.banchi.StockInfo.AdditionalEntry\x1a\x31\n\x0f\x41\x64\x64itionalEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x02\n\x13StockTimeSeriesData\x12(\n\x0bopen_prices\x18\x01 \x01(\x0b\x32\x13.banchi.DailyTicker\x12(\n\x0bhigh_prices\x18\x02 \x01(\x0b\x32\x13.banchi.DailyTicker\x12\'\n\nlow_prices\x18\x03 \x01(\x0b\x32\x13.banchi.DailyTicker\x12)\n\x0c\x63lose_prices\x18\x04 \x01(\x0b\x32\x13.banchi.DailyTicker\x12$\n\x07volumes\x18\x05 \x01(\x0b\x32\x13.banchi.DailyTicker\x12\"\n\x05vwaps\x18\x06 \x01(\x0b\x32\x13.banchi.DailyTicker\"\xb4\x02\n\x05Stock\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x12\n\nspot_price\x18\x02 \x01(\x01\x12\x17\n\x0fvolatility_flat\x18\x03 \x01(\x01\x12$\n\tdividends\x18\x04 \x01(\x0b\x32\x11.banchi.Dividends\x12\x13\n\x0b\x62orrow_cost\x18\x05 \x01(\x01\x12\"\n\x08\x63urrency\x18\x08 \x01(\x0b\x32\x10.banchi.Currency\x12\"\n\x08\x63\x61lendar\x18\x0e \x01(\x0b\x32\x10.banchi.Calendar\x12\x30\n\x0btime_series\x18\x0f \x01(\x0b\x32\x1b.banchi.StockTimeSeriesData\x12\x1f\n\x04info\x18\x33 \x01(\x0b\x32\x11.banchi.StockInfoJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stock_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STOCKINFO_ADDITIONALENTRY._options = None
  _STOCKINFO_ADDITIONALENTRY._serialized_options = b'8\001'
  _CASHDIVIDEND._serialized_start=114
  _CASHDIVIDEND._serialized_end=174
  _PROPORTIONALDIVIDEND._serialized_start=176
  _PROPORTIONALDIVIDEND._serialized_end=244
  _DIVIDENDYIELDENTRY._serialized_start=246
  _DIVIDENDYIELDENTRY._serialized_end=315
  _DIVIDENDS._serialized_start=318
  _DIVIDENDS._serialized_end=593
  _DIVIDENDS_TYPE._serialized_start=550
  _DIVIDENDS_TYPE._serialized_end=593
  _STOCKINFO._serialized_start=596
  _STOCKINFO._serialized_end=793
  _STOCKINFO_ADDITIONALENTRY._serialized_start=744
  _STOCKINFO_ADDITIONALENTRY._serialized_end=793
  _STOCKTIMESERIESDATA._serialized_start=796
  _STOCKTIMESERIESDATA._serialized_end=1059
  _STOCK._serialized_start=1062
  _STOCK._serialized_end=1370
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model_parameters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16model_parameters.proto\x12\x06\x62\x61nchi\"t\n\x0fModelParameters\x12\x37\n\x13\x64iscretisation_type\x18\x01 \x01(\x0e\x32\x1a.banchi.DiscretisationType\x12\x12\n\ntime_steps\x18\x03 \x01(\x05\x12\x14\n\x0cstock_points\x18\x04 \x01(\x05*E\n\x12\x44iscretisationType\x12\x0c\n\x08\x42\x41LANCED\x10\x00\x12\n\n\x06SPARSE\x10\x01\x12\t\n\x05\x44\x45NSE\x10\x02\x12\n\n\x06MANUAL\x10\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_parameters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISCRETISATIONTYPE._serialized_start=152
  _DISCRETISATIONTYPE._serialized_end=221
  _MODELPARAMETERS._serialized_start=34
  _MODELPARAMETERS._serialized_end=150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: conversion.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import enums_pb2 as enums__pb2
import trigger_pb2 as trigger__pb2
import date_pb2 as date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63onversion.proto\x12\x06\x62\x61nchi\x1a\x0b\x65nums.proto\x1a\rtrigger.proto\x1a\ndate.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8b\x03\n\x0b\x43oCoTrigger\x12\r\n\x05level\x18\x01 \x01(\x01\x12\"\n\x04type\x18\x03 \x01(\x0e\x32\x14.banchi.Trigger.Type\x12\x33\n\x0blevel_basis\x18\x04 \x01(\x0e\x32\x1e.banchi.CoCoTrigger.LevelBasis\x12\x35\n\x0egrace_required\x18\x06 \x01(\x0e\x32\x1d.banchi.Trigger.GraceRequired\x12\x1c\n\x14\x64\x61ys_in_grace_period\x18\x07 \x01(\x05\x12\x14\n\x0cgrace_period\x18\x08 \x01(\x05\x12\x30\n\x16grace_period_days_type\x18\t \x01(\x0e\x32\x10.banchi.DaysType\x12\x1a\n\x12grace_period_delay\x18\x0c \x01(\x05\x12\x36\n\x1cgrace_period_delay_days_type\x18\r \x01(\x0e\x32\x10.banchi.DaysType\"#\n\nLevelBasis\x12\x07\n\x03PAR\x10\x00\x12\x0c\n\x08\x41\x43\x43RETED\x10\x01\"v\n\nCoCoPeriod\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12$\n\x07trigger\x18\x04 \x01(\x0b\x32\x13.banchi.CoCoTrigger\"\xeb\x02\n\x14\x43ontingentConversion\x12$\n\x08schedule\x18\x01 \x03(\x0b\x32\x12.banchi.CoCoPeriod\x12?\n\x17trigger_check_frequency\x18\x02 \x01(\x0e\x32\x1e.banchi.Trigger.CheckFrequency\x12\x33\n\x1dtrigger_check_generating_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\x46\n\x1dtrigger_share_price_reference\x18\x06 \x01(\x0e\x32\x1f.banchi.SharePriceReferenceType\x12\x39\n\x14trigger_fx_reference\x18\x07 \x01(\x0e\x32\x1b.banchi.FXRateReferenceType\x12\x34\n\x0eparity_trigger\x18\n \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\x88\x01\n\x14\x43onversionValueEntry\x12$\n\x0e\x65\x66\x66\x65\x63tive_from\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x1a\n\x12lower_strike_value\x18\x03 \x01(\x01\x12\x11\n\tconfirmed\x18\x05 \x01(\x08\x12\x0c\n\x04note\x18\x06 \x01(\t\"\xe2\x02\n\x1d\x43onversionSettlementAveraging\x12\x17\n\x0f\x63\x61sh_percentage\x18\x01 \x01(\x01\x12R\n\x14\x63\x61sh_reference_value\x18\x02 \x01(\x0e\x32\x34.banchi.ConversionSettlementAveraging.ReferenceValue\x12\x0e\n\x06period\x18\x03 \x01(\x05\x12\x15\n\rperiod_begins\x18\x04 \x01(\x05\x12>\n\x15share_price_reference\x18\x06 \x01(\x0e\x32\x1f.banchi.SharePriceReferenceType\x12\x31\n\x0c\x66x_reference\x18\x07 \x01(\x0e\x32\x1b.banchi.FXRateReferenceType\":\n\x0eReferenceValue\x12\x07\n\x03PAR\x10\x00\x12\n\n\x06PARITY\x10\x01\x12\x13\n\x0f\x41\x43\x43RETED_AMOUNT\x10\x02\"\xfc\x05\n\nConversion\x12\x45\n\x15\x63onversion_value_type\x18\x01 \x01(\x0e\x32&.banchi.Conversion.ConversionValueType\x12 \n\x18initial_conversion_value\x18\x02 \x01(\x01\x12\"\n\x1ainitial_lower_strike_value\x18\t \x01(\x01\x12\x42\n\x1cprevailing_conversion_values\x18\n \x03(\x0b\x32\x1c.banchi.ConversionValueEntry\x12.\n\x08\x65xercise\x18\x03 \x01(\x0e\x32\x1c.banchi.ExerciseScheduleType\x12)\n\x13\x66irst_exercise_date\x18\x04 \x01(\x0b\x32\x0c.banchi.Date\x12)\n\x13\x66inal_exercise_date\x18\x05 \x01(\x0b\x32\x0c.banchi.Date\x12+\n\x05\x63o_co\x18\x08 \x01(\x0b\x32\x1c.banchi.ContingentConversion\x12\x43\n\x14settlement_averaging\x18\x0b \x01(\x0b\x32%.banchi.ConversionSettlementAveraging\x12\x19\n\x11keep_final_coupon\x18\r \x01(\x08\x12\x19\n\x11is_cross_currency\x18\x0e \x01(\x08\x12\x15\n\rfixed_fx_rate\x18\x0f \x01(\x01\x12\x36\n\x0e\x66ixed_fx_basis\x18\x10 \x01(\x0e\x32\x1e.banchi.ContractualFXRateBasis\x12\x1f\n\x17\x63\x61sh_paid_on_conversion\x18\x14 \x01(\x01\x12\x45\n\x1bpeps_early_conversion_ratio\x18( \x01(\x0e\x32 .banchi.PEPSEarlyConversionRatio\"8\n\x13\x43onversionValueType\x12\x0b\n\x07PREMIUM\x10\x00\x12\t\n\x05PRICE\x10\x01\x12\t\n\x05RATIO\x10\x02*=\n\x18PEPSEarlyConversionRatio\x12\x0b\n\x07MINIMUM\x10\x00\x12\x14\n\x10SAME_AS_MATURITY\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'conversion_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PEPSEARLYCONVERSIONRATIO._serialized_start=2247
  _PEPSEARLYCONVERSIONRATIO._serialized_end=2308
  _COCOTRIGGER._serialized_start=101
  _COCOTRIGGER._serialized_end=496
  _COCOTRIGGER_LEVELBASIS._serialized_start=461
  _COCOTRIGGER_LEVELBASIS._serialized_end=496
  _COCOPERIOD._serialized_start=498
  _COCOPERIOD._serialized_end=616
  _CONTINGENTCONVERSION._serialized_start=619
  _CONTINGENTCONVERSION._serialized_end=982
  _CONVERSIONVALUEENTRY._serialized_start=985
  _CONVERSIONVALUEENTRY._serialized_end=1121
  _CONVERSIONSETTLEMENTAVERAGING._serialized_start=1124
  _CONVERSIONSETTLEMENTAVERAGING._serialized_end=1478
  _CONVERSIONSETTLEMENTAVERAGING_REFERENCEVALUE._serialized_start=1420
  _CONVERSIONSETTLEMENTAVERAGING_REFERENCEVALUE._serialized_end=1478
  _CONVERSION._serialized_start=1481
  _CONVERSION._serialized_end=2245
  _CONVERSION_CONVERSIONVALUETYPE._serialized_start=2189
  _CONVERSION_CONVERSIONVALUETYPE._serialized_end=2245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: object_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11object_info.proto\x12\x06\x62\x61nchi\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8d\x01\n\nObjectInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eschema_version\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12snapshot_parent_id\x18\x08 \x01(\t\x12\x31\n\rsnapshot_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestampb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'object_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OBJECTINFO._serialized_start=63
  _OBJECTINFO._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interest_rate_index.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19interest_rate_index.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"6\n\nFixingRate\x12\x1a\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\x0c\n\x04rate\x18\x02 \x01(\x01\"\x95\x01\n\x11InterestRateIndex\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x07\x66ixings\x18\x03 \x03(\x0b\x32\x12.banchi.FixingRate\x12#\n\tday_count\x18\x06 \x01(\x0e\x32\x10.banchi.DayCountJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interest_rate_index_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIXINGRATE._serialized_start=68
  _FIXINGRATE._serialized_end=122
  _INTERESTRATEINDEX._serialized_start=125
  _INTERESTRATEINDEX._serialized_end=274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: matrix.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmatrix.proto\x12\x06\x62\x61nchi\"8\n\x0c\x44oubleMatrix\x12\x0c\n\x04rows\x18\x01 \x01(\r\x12\x0c\n\x04\x63ols\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'matrix_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOUBLEMATRIX._serialized_start=24
  _DOUBLEMATRIX._serialized_end=80
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: calendar.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63\x61lendar.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"\x87\x01\n\x08\x43\x61lendar\x12\"\n\x08weekends\x18\x02 \x01(\x0e\x32\x10.banchi.Weekends\x12\x1e\n\x08holidays\x18\x03 \x03(\x0b\x32\x0c.banchi.Date\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t*$\n\x08Weekends\x12\x0b\n\x07SAT_SUN\x10\x00\x12\x0b\n\x07\x46RI_SAT\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'calendar_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WEEKENDS._serialized_start=195
  _WEEKENDS._serialized_end=231
  _CALENDAR._serialized_start=58
  _CALENDAR._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bond.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import enums_pb2 as enums__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbond.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0b\x65nums.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xcd\x01\n\rCouponDetails\x12\x37\n\trate_type\x18\x01 \x01(\x0e\x32$.banchi.CouponDetails.CouponRateType\x12\x12\n\nfixed_rate\x18\x02 \x01(\x01\x12+\n\tfrequency\x18\x04 \x01(\x0e\x32\x18.banchi.PaymentFrequency\x12\x17\n\x0f\x66loating_spread\x18\n \x01(\x01\")\n\x0e\x43ouponRateType\x12\t\n\x05\x46IXED\x10\x00\x12\x0c\n\x08\x46LOATING\x10\x01\"V\n\x0c\x43ouponStream\x12\x1e\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12&\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x15.banchi.CouponDetails\"\x96\x01\n\x0f\x42ondMarketPrice\x12\r\n\x05price\x18\x01 \x01(\x01\x12\r\n\x05\x64irty\x18\x02 \x01(\x08\x12\x35\n\nquote_type\x18\x03 \x01(\x0e\x32!.banchi.BondMarketPrice.QuoteType\".\n\tQuoteType\x12\x17\n\x13PERCENT_OF_NOTIONAL\x10\x00\x12\x08\n\x04\x43\x41SH\x10\x01\"\x9f\x08\n\x0b\x42ondDetails\x12 \n\nissue_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12#\n\rmaturity_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\x10\n\x08notional\x18\x04 \x01(\x01\x12\x1e\n\x16use_structured_coupons\x18\x06 \x01(\x08\x12\x32\n\x13\x66lat_coupon_details\x18\x07 \x01(\x0b\x32\x15.banchi.CouponDetails\x12,\n\x0e\x63oupon_streams\x18\x08 \x03(\x0b\x32\x14.banchi.CouponStream\x12+\n\x11\x61\x63\x63rual_day_count\x18\t \x01(\x0e\x32\x10.banchi.DayCount\x12\x1b\n\x13settlement_interval\x18\x0b \x01(\x05\x12\x14\n\x0cis_perpetual\x18\x0c \x01(\x08\x12?\n\x1c\x66loating_reference_rate_type\x18\r \x01(\x0e\x32\x19.banchi.ReferenceRateType\x12\x30\n\taccretion\x18\x0f \x01(\x0b\x32\x1d.banchi.BondDetails.Accretion\x12\x33\n\rissue_percent\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10maturity_percent\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x17payment_roll_convention\x18\x14 \x01(\x0e\x32\x16.banchi.RollConvention\x1a\xbb\x03\n\tAccretion\x12\x45\n\x0f\x64\x65\x66inition_type\x18\x01 \x01(\x0e\x32,.banchi.BondDetails.Accretion.DefinitionType\x12(\n\x08schedule\x18\x02 \x03(\x0b\x32\x16.banchi.StartDateValue\x12\x1e\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\x39\n\trate_type\x18\x05 \x01(\x0e\x32&.banchi.BondDetails.Accretion.RateType\x12-\n\x10rate_compounding\x18\x06 \x01(\x0e\x32\x13.banchi.Compounding\x12(\n\x0erate_day_count\x18\x07 \x01(\x0e\x32\x10.banchi.DayCount\"Z\n\x0e\x44\x65\x66initionType\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x46IXED_FROM_ISSUE\x10\x01\x12\x15\n\x11\x46IXED_TO_MATURITY\x10\x02\x12\x11\n\rIMPLICIT_RATE\x10\x03\"-\n\x08RateType\x12\n\n\x06SIMPLE\x10\x00\x12\x15\n\x11YIELD_TO_MATURITY\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bond_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COUPONDETAILS._serialized_start=80
  _COUPONDETAILS._serialized_end=285
  _COUPONDETAILS_COUPONRATETYPE._serialized_start=244
  _COUPONDETAILS_COUPONRATETYPE._serialized_end=285
  _COUPONSTREAM._serialized_start=287
  _COUPONSTREAM._serialized_end=373
  _BONDMARKETPRICE._serialized_start=376
  _BONDMARKETPRICE._serialized_end=526
  _BONDMARKETPRICE_QUOTETYPE._serialized_start=480
  _BONDMARKETPRICE_QUOTETYPE._serialized_end=526
  _BONDDETAILS._serialized_start=529
  _BONDDETAILS._serialized_end=1584
  _BONDDETAILS_ACCRETION._serialized_start=1141
  _BONDDETAILS_ACCRETION._serialized_end=1584
  _BONDDETAILS_ACCRETION_DEFINITIONTYPE._serialized_start=1447
  _BONDDETAILS_ACCRETION_DEFINITIONTYPE._serialized_end=1537
  _BONDDETAILS_ACCRETION_RATETYPE._serialized_start=1539
  _BONDDETAILS_ACCRETION_RATETYPE._serialized_end=1584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: warrant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import currency_pb2 as currency__pb2
import date_pb2 as date__pb2
import matrix_pb2 as matrix__pb2
import offset_pb2 as offset__pb2
import output_pb2 as output__pb2
import yield_curve_pb2 as yield__curve__pb2
import stock_pb2 as stock__pb2
import enums_pb2 as enums__pb2
import model_parameters_pb2 as model__parameters__pb2
import object_info_pb2 as object__info__pb2
import warrant_call_schedule_pb2 as warrant__call__schedule__pb2
import ticker_pb2 as ticker__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rwarrant.proto\x12\x06\x62\x61nchi\x1a\x0e\x63urrency.proto\x1a\ndate.proto\x1a\x0cmatrix.proto\x1a\x0coffset.proto\x1a\x0coutput.proto\x1a\x11yield_curve.proto\x1a\x0bstock.proto\x1a\x0b\x65nums.proto\x1a\x16model_parameters.proto\x1a\x11object_info.proto\x1a\x1bwarrant_call_schedule.proto\x1a\x0cticker.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9e\x01\n\x10\x43\x61shlessExercise\x12\x30\n\x12table_offset_units\x18\x02 \x01(\x0e\x32\x14.banchi.Offset.Units\x12\x15\n\rtable_strikes\x18\x03 \x03(\x01\x12\x15\n\rtable_offsets\x18\x04 \x03(\x05\x12*\n\x0ctable_values\x18\x05 \x01(\x0b\x32\x14.banchi.DoubleMatrix\"\x7f\n\x14WarrantMergerDetails\x12\x1f\n\x17\x65xercise_only_on_merger\x18\x01 \x01(\x08\x12\x1c\n\x14new_term_post_merger\x18\x02 \x01(\x08\x12(\n\x10post_merger_term\x18\x03 \x01(\x0b\x32\x0e.banchi.Offset\"\x82\x03\n\x07Warrant\x12#\n\rmaturity_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\x16\n\x0e\x65xercise_price\x18\x03 \x01(\x01\x12.\n\x08\x65xercise\x18\x04 \x01(\x0e\x32\x1c.banchi.ExerciseScheduleType\x12*\n\x05\x63\x61lls\x18\x07 \x01(\x0b\x32\x1b.banchi.WarrantCallSchedule\x12\x33\n\x11\x63\x61shless_exercise\x18\x08 \x01(\x0b\x32\x18.banchi.CashlessExercise\x12\"\n\x08\x63urrency\x18\t \x01(\x0b\x32\x10.banchi.Currency\x12\x38\n\x12shares_per_warrant\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x17\n\x0f\x61ttached_shares\x18\r \x01(\x01\x12,\n\x06merger\x18\x0f \x01(\x0b\x32\x1c.banchi.WarrantMergerDetailsJ\x04\x08\x01\x10\x02\"\x95\x02\n\x0eWarrantOutputs\x12\"\n\x04theo\x18\x01 \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05\x64\x65lta\x18\n \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05gamma\x18\x0b \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05theta\x18\x0c \x01(\x0b\x32\x14.banchi.OutputDouble\x12\x36\n\x18implied_merger_intensity\x18\x14 \x01(\x0b\x32\x14.banchi.OutputDouble\x12\x38\n\x1aimplied_merger_probability\x18\x15 \x01(\x0b\x32\x14.banchi.OutputDouble\"\x98\x01\n\x0bWarrantInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x0e \x01(\t\x12\x37\n\nadditional\x18\x0f \x03(\x0b\x32#.banchi.WarrantInfo.AdditionalEntry\x1a\x31\n\x0f\x41\x64\x64itionalEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x01\n\x12WarrantMergerModel\x12\'\n\nmodel_type\x18\x01 \x01(\x0e\x32\x13.banchi.MergerModel\x12\x11\n\tintensity\x18\x02 \x01(\x01\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12<\n\x16post_merger_volatility\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17post_merger_stock_price\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"B\n\x15WarrantTimeSeriesData\x12)\n\x0c\x63lose_prices\x18\x04 \x01(\x0b\x32\x13.banchi.DailyTicker\"\xd3\x03\n\x0bWarrantData\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12$\n\x0evaluation_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12#\n\ninstrument\x18\x03 \x01(\x0b\x32\x0f.banchi.Warrant\x12\x1c\n\x05stock\x18\x04 \x01(\x0b\x32\r.banchi.Stock\x12\x36\n\x1ainstrument_risk_free_curve\x18\x05 \x01(\x0b\x32\x12.banchi.YieldCurve\x12\x31\n\x10model_parameters\x18\x06 \x01(\x0b\x32\x17.banchi.ModelParameters\x12\x14\n\x0cmarket_price\x18\t \x01(\x01\x12\x30\n\x0cmerger_model\x18\x0b \x01(\x0b\x32\x1a.banchi.WarrantMergerModel\x12\x32\n\x0btime_series\x18\x0e \x01(\x0b\x32\x1d.banchi.WarrantTimeSeriesData\x12\'\n\x07outputs\x18\x0f \x01(\x0b\x32\x16.banchi.WarrantOutputs\x12!\n\x04info\x18\x32 \x01(\x0b\x32\x13.banchi.WarrantInfoJ\x04\x08\x01\x10\x02\"4\n\x0eWarrantCalcSet\x12\"\n\x05\x63\x61lcs\x18\x01 \x03(\x0b\x32\x13.banchi.WarrantData*7\n\x0bMergerModel\x12\x08\n\x04NONE\x10\x00\x12\r\n\tINTENSITY\x10\x01\x12\x0f\n\x0bPROBABILITY\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'warrant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WARRANTINFO_ADDITIONALENTRY._options = None
  _WARRANTINFO_ADDITIONALENTRY._serialized_options = b'8\001'
  _MERGERMODEL._serialized_start=2193
  _MERGERMODEL._serialized_end=2248
  _CASHLESSEXERCISE._serialized_start=259
  _CASHLESSEXERCISE._serialized_end=417
  _WARRANTMERGERDETAILS._serialized_start=419
  _WARRANTMERGERDETAILS._serialized_end=546
  _WARRANT._serialized_start=549
  _WARRANT._serialized_end=935
  _WARRANTOUTPUTS._serialized_start=938
  _WARRANTOUTPUTS._serialized_end=1215
  _WARRANTINFO._serialized_start=1218
  _WARRANTINFO._serialized_end=1370
  _WARRANTINFO_ADDITIONALENTRY._serialized_start=1321
  _WARRANTINFO_ADDITIONALENTRY._serialized_end=1370
  _WARRANTMERGERMODEL._serialized_start=1373
  _WARRANTMERGERMODEL._serialized_end=1599
  _WARRANTTIMESERIESDATA._serialized_start=1601
  _WARRANTTIMESERIESDATA._serialized_end=1667
  _WARRANTDATA._serialized_start=1670
  _WARRANTDATA._serialized_end=2137
  _WARRANTCALCSET._serialized_start=2139
  _WARRANTCALCSET._serialized_end=2191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: market.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmarket.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\"A\n\x06Region\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\"A\n\x06Sector\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'market_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGION._serialized_start=43
  _REGION._serialized_end=108
  _SECTOR._serialized_start=110
  _SECTOR._serialized_end=175
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trigger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtrigger.proto\x12\x06\x62\x61nchi\"\xf6\x01\n\x07Trigger\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UPSIDE\x10\x01\x12\x0c\n\x08\x44OWNSIDE\x10\x02\"0\n\rGraceRequired\x12\x12\n\x0e\x44\x41YS_IN_PERIOD\x10\x00\x12\x0b\n\x07\x41VERAGE\x10\x01\"\x8c\x01\n\x0e\x43heckFrequency\x12\x16\n\x12\x43HECK_CONTINUOUSLY\x10\x00\x12\x11\n\rCHECK_MONTHLY\x10\x01\x12\x13\n\x0f\x43HECK_QUARTERLY\x10\x02\x12\x16\n\x12\x43HECK_SEMIANNUALLY\x10\x03\x12\x12\n\x0e\x43HECK_ANNUALLY\x10\x04\x12\x0e\n\nCHECK_ONCE\x10\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'trigger_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRIGGER._serialized_start=26
  _TRIGGER._serialized_end=272
  _TRIGGER_TYPE._serialized_start=37
  _TRIGGER_TYPE._serialized_end=79
  _TRIGGER_GRACEREQUIRED._serialized_start=81
  _TRIGGER_GRACEREQUIRED._serialized_end=129
  _TRIGGER_CHECKFREQUENCY._serialized_start=132
  _TRIGGER_CHECKFREQUENCY._serialized_end=272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cashflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import output_pb2 as output__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63\x61shflows.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0coutput.proto\"\xcf\x01\n\x11ProjectedCashflow\x12\"\n\x0cpayment_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\x10\n\x08\x63\x61shflow\x18\x02 \x01(\x01\x12#\n\raccrual_start\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12!\n\x0b\x61\x63\x63rual_end\x18\x04 \x01(\x0b\x32\x0c.banchi.Date\x12\x0c\n\x04rate\x18\x05 \x01(\x01\x12\n\n\x02pv\x18\x06 \x01(\x01\x12\"\n\x04type\x18\x07 \x01(\x0e\x32\x14.banchi.CashflowType\"f\n\x18OutputProjectedCashflows\x12(\n\x05value\x18\x01 \x03(\x0b\x32\x19.banchi.ProjectedCashflow\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfo*)\n\x0c\x43\x61shflowType\x12\n\n\x06\x43oupon\x10\x00\x12\r\n\tPrincipal\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cashflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CASHFLOWTYPE._serialized_start=367
  _CASHFLOWTYPE._serialized_end=408
  _PROJECTEDCASHFLOW._serialized_start=54
  _PROJECTEDCASHFLOW._serialized_end=261
  _OUTPUTPROJECTEDCASHFLOWS._serialized_start=263
  _OUTPUTPROJECTEDCASHFLOWS._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_preferences.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16user_preferences.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\" \n\x10ObjectGridColumn\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xec\x01\n\x0eObjectGridView\x12)\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x18.banchi.ObjectGridColumn\x12\x18\n\x10sort_column_name\x18\x02 \x01(\t\x12<\n\x0esort_direction\x18\x03 \x01(\x0e\x32$.banchi.ObjectGridView.SortDirection\x12\x10\n\x08paginate\x18\x04 \x01(\x08\x12\x15\n\rrows_per_page\x18\x05 \x01(\x05\".\n\rSortDirection\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\"\x9b\x03\n\x0fUserPreferences\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12,\n\x05theme\x18\x03 \x01(\x0e\x32\x1d.banchi.UserPreferences.Theme\x12\x15\n\rshow_tooltips\x18\x07 \x01(\x08\x12\x15\n\rtooltip_delay\x18\x08 \x01(\x01\x12G\n\x11object_grid_views\x18\x04 \x03(\x0b\x32,.banchi.UserPreferences.ObjectGridViewsEntry\x12$\n\x1c\x61nonymize_saved_calculations\x18\x05 \x01(\x08\x12%\n\x1dsave_convertible_calculations\x18\x06 \x01(\x08\x1aN\n\x14ObjectGridViewsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.banchi.ObjectGridView:\x02\x38\x01\"\x1c\n\x05Theme\x12\t\n\x05LIGHT\x10\x00\x12\x08\n\x04\x44\x41RK\x10\x01J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_preferences_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._options = None
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_options = b'8\001'
  _OBJECTGRIDCOLUMN._serialized_start=53
  _OBJECTGRIDCOLUMN._serialized_end=85
  _OBJECTGRIDVIEW._serialized_start=88
  _OBJECTGRIDVIEW._serialized_end=324
  _OBJECTGRIDVIEW_SORTDIRECTION._serialized_start=278
  _OBJECTGRIDVIEW_SORTDIRECTION._serialized_end=324
  _USERPREFERENCES._serialized_start=327
  _USERPREFERENCES._serialized_end=738
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_start=624
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_end=702
  _USERPREFERENCES_THEME._serialized_start=704
  _USERPREFERENCES_THEME._serialized_end=732
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: date.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ndate.proto\x12\x06\x62\x61nchi\"*\n\x04\x44\x61te\x12\x15\n\rserial_number\x18\x01 \x01(\x05\x12\x0b\n\x03iso\x18\x02 \x01(\t\"6\n\tDateValue\x12\x1a\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01\"A\n\x0eStartDateValue\x12 \n\nstart_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01\"=\n\x0c\x45ndDateValue\x12\x1e\n\x08\x65nd_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01*h\n\x08\x44\x61yCount\x12\x0b\n\x07\x41\x43T_365\x10\x00\x12\x0b\n\x07\x41\x43T_360\x10\x01\x12\x10\n\x0c\x41\x43T_ACT_ISDA\x10\x02\x12\x10\n\x0c\x41\x43T_ACT_ISMA\x10\x03\x12\x0e\n\nTHIRTY_360\x10\x04\x12\x0e\n\nTHIRTY_365\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'date_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAYCOUNT._serialized_start=252
  _DAYCOUNT._serialized_end=356
  _DATE._serialized_start=22
  _DATE._serialized_end=64
  _DATEVALUE._serialized_start=66
  _DATEVALUE._serialized_end=120
  _STARTDATEVALUE._serialized_start=122
  _STARTDATEVALUE._serialized_end=187
  _ENDDATEVALUE._serialized_start=189
  _ENDDATEVALUE._serialized_end=250
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0coffset.proto\x12\x06\x62\x61nchi\"\x84\x01\n\x06Offset\x12\r\n\x05value\x18\x01 \x01(\x05\x12#\n\x05units\x18\x02 \x01(\x0e\x32\x14.banchi.Offset.Units\"F\n\x05Units\x12\x08\n\x04\x44\x41YS\x10\x00\x12\x11\n\rBUSINESS_DAYS\x10\x01\x12\t\n\x05WEEKS\x10\x02\x12\n\n\x06MONTHS\x10\x03\x12\t\n\x05YEARS\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'offset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OFFSET._serialized_start=25
  _OFFSET._serialized_end=157
  _OFFSET_UNITS._serialized_start=87
  _OFFSET_UNITS._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dividend_protection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import enums_pb2 as enums__pb2
import output_pb2 as output__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x64ividend_protection.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0b\x65nums.proto\x1a\x0coutput.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf3\x03\n\x1b\x44ividendProtectionThreshold\x12\x1e\n\x08\x65nd_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.banchi.DividendProtectionThreshold.Type\x12\x11\n\tthreshold\x18\x03 \x01(\x01\x12-\n\x07trigger\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12M\n\x10period_frequency\x18\x05 \x01(\x0e\x32\x33.banchi.DividendProtectionThreshold.PeriodFrequency\"\xcd\x01\n\x0fPeriodFrequency\x12\x15\n\x11\x46INANCIAL_QUARTER\x10\x00\x12\x12\n\x0e\x46INANCIAL_YEAR\x10\x01\x12\x14\n\x10\x43\x41LENDAR_QUARTER\x10\x02\x12\x11\n\rCALENDAR_YEAR\x10\x03\x12\x13\n\x0f\x41NNUAL_FROM_END\x10\x06\x12\x17\n\x13SEMIANNUAL_FROM_END\x10\x07\x12\x16\n\x12QUARTERLY_FROM_END\x10\x08\x12\x14\n\x10MONTHLY_FROM_END\x10\t\x12\n\n\x06SINGLE\x10\x0c\"\x1b\n\x04Type\x12\x08\n\x04\x43\x41SH\x10\x00\x12\t\n\x05YIELD\x10\x01\"\x81\x08\n\x12\x44ividendProtection\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.banchi.DividendProtection.Type\x12\x1e\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12L\n\x14protection_frequency\x18\x04 \x01(\x0e\x32..banchi.DividendProtection.ProtectionFrequency\x12\x30\n\x1aprotection_generating_date\x18\x05 \x01(\x0b\x32\x0c.banchi.Date\x12\x46\n\x11\x61\x64justment_factor\x18\x06 \x01(\x0e\x32+.banchi.DividendProtection.AdjustmentFactor\x12\x37\n\nthresholds\x18\x08 \x03(\x0b\x32#.banchi.DividendProtectionThreshold\x12L\n\x14\x61\x64justment_direction\x18\n \x01(\x0e\x32..banchi.DividendProtection.AdjustmentDirection\x12\x18\n\x10\x61veraging_period\x18\x0b \x01(\x05\x12S\n\x1d\x61veraging_reference_date_type\x18\x0c \x01(\x0e\x32,.banchi.DividendProtection.ReferenceDateType\x12#\n\x1b\x61veraging_period_end_offset\x18\r \x01(\x05\x12\x42\n\x19\x61veraging_price_reference\x18\x0f \x01(\x0e\x32\x1f.banchi.SharePriceReferenceType\x12\x18\n\x10\x63\x61sh_passthrough\x18\x0e \x01(\x01\"%\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05RATIO\x10\x01\x12\x08\n\x04\x43\x41SH\x10\x02\"]\n\x13ProtectionFrequency\x12\x0e\n\nON_EX_DATE\x10\x00\x12\n\n\x06\x41NNUAL\x10\x01\x12\x0e\n\nSEMIANNUAL\x10\x02\x12\r\n\tQUARTERLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\"O\n\x10\x41\x64justmentFactor\x12\x0c\n\x08STANDARD\x10\x00\x12\x16\n\x12\x44\x45NOMINATOR_EX_DIV\x10\x01\x12\x15\n\x11NUMERATOR_CUM_DIV\x10\x02\"8\n\x13\x41\x64justmentDirection\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x0f\n\x0bUP_AND_DOWN\x10\x02\"D\n\x11ReferenceDateType\x12\x0b\n\x07\x45X_DATE\x10\x00\x12\x0f\n\x0bRECORD_DATE\x10\x01\x12\x11\n\rDECLARED_DATE\x10\x02J\x04\x08\x07\x10\x08\"\xfd\x01\n\x1bProjectedDividendProtection\x12%\n\x0fprotection_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12,\n\x16threshold_period_start\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12*\n\x14threshold_period_end\x18\x04 \x01(\x0b\x32\x0c.banchi.Date\x12\x17\n\x0fshare_reference\x18\x05 \x01(\x01\x12\x11\n\tthreshold\x18\x06 \x01(\x01\x12\x14\n\x0c\x64ividend_sum\x18\t \x01(\x01\x12\r\n\x05ratio\x18\x0b \x01(\x01\x12\x0c\n\x04\x63\x61sh\x18\x0c \x01(\x01\"y\n!OutputProjectedDividendProtection\x12\x32\n\x05value\x18\x01 \x03(\x0b\x32#.banchi.ProjectedDividendProtection\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dividend_protection_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIVIDENDPROTECTIONTHRESHOLD._serialized_start=109
  _DIVIDENDPROTECTIONTHRESHOLD._serialized_end=608
  _DIVIDENDPROTECTIONTHRESHOLD_PERIODFREQUENCY._serialized_start=374
  _DIVIDENDPROTECTIONTHRESHOLD_PERIODFREQUENCY._serialized_end=579
  _DIVIDENDPROTECTIONTHRESHOLD_TYPE._serialized_start=581
  _DIVIDENDPROTECTIONTHRESHOLD_TYPE._serialized_end=608
  _DIVIDENDPROTECTION._serialized_start=611
  _DIVIDENDPROTECTION._serialized_end=1636
  _DIVIDENDPROTECTION_TYPE._serialized_start=1289
  _DIVIDENDPROTECTION_TYPE._serialized_end=1326
  _DIVIDENDPROTECTION_PROTECTIONFREQUENCY._serialized_start=1328
  _DIVIDENDPROTECTION_PROTECTIONFREQUENCY._serialized_end=1421
  _DIVIDENDPROTECTION_ADJUSTMENTFACTOR._serialized_start=1423
  _DIVIDENDPROTECTION_ADJUSTMENTFACTOR._serialized_end=1502
  _DIVIDENDPROTECTION_ADJUSTMENTDIRECTION._serialized_start=1504
  _DIVIDENDPROTECTION_ADJUSTMENTDIRECTION._serialized_end=1560
  _DIVIDENDPROTECTION_REFERENCEDATETYPE._serialized_start=1562
  _DIVIDENDPROTECTION_REFERENCEDATETYPE._serialized_end=1630
  _PROJECTEDDIVIDENDPROTECTION._serialized_start=1639
  _PROJECTEDDIVIDENDPROTECTION._serialized_end=1892
  _OUTPUTPROJECTEDDIVIDENDPROTECTION._serialized_start=1894
  _OUTPUTPROJECTEDDIVIDENDPROTECTION._serialized_end=2015
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: convertible_calc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
import object_info_pb2 as object__info__pb2
import convertible_pb2 as convertible__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63onvertible_calc.proto\x12\x06\x62\x61nchi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11object_info.proto\x1a\x11\x63onvertible.proto\"\xd9\x01\n\x18\x43onvertibleCalcOverrides\x12\x36\n\x10stock_spot_price\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15stock_volatility_flat\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"instrument_credit_data_flat_spread\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xdb\x01\n\x0f\x43onvertibleCalc\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12-\n\tcalc_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x04 \x01(\t\x12,\n\x0b\x63onvertible\x18\x05 \x01(\x0b\x32\x17.banchi.ConvertibleData\x12\x33\n\toverrides\x18\x06 \x01(\x0b\x32 .banchi.ConvertibleCalcOverridesJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'convertible_calc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONVERTIBLECALCOVERRIDES._serialized_start=138
  _CONVERTIBLECALCOVERRIDES._serialized_end=355
  _CONVERTIBLECALC._serialized_start=358
  _CONVERTIBLECALC._serialized_end=577
# @@protoc_insertion_point(module_scope)
